@@ -94,21 +94,18 @@ sub set_row_pos {
         $self->{log}->debug("no data");
         $found = 0;
     } elsif ( $pos < $self->{row}->{last_row} + 1 && $pos >= 0 ) {
-        $self->{log}
-          ->debug( "setting current row to an existing row at pos ", $pos );
+	    # $self->{log}->debug( "setting current row to an existing row at pos ", $pos );
         $self->{row}->{pos} = $pos;
 
 # $self->{log}->debug("set_row at pos : " . $pos . " pk: " . join(" ", @{ $self->{data}[$pos] }) . " class: " . $self->{rs}->result_class);
 #die Dumper( $self->{data}[$pos] );
         my $r;
         if ( $self->{usefind} ) {
-            $self->{log}
-              ->debug( "usefind is true rs count: " . $self->{rs}->count );
+		#$self->{log}->debug( "usefind is true rs count: " . $self->{rs}->count );
 
       # my $sql =  $self->{rs}->as_query;
       # $self->{log}->debug("sql  and bound values : " .  join(" * ", @$$sql) );
-            $self->{log}
-              ->debug( "searching " . join( " ", @{ $self->{data}[$pos] } ) );
+      #$self->{log}->debug( "searching " . join( " ", @{ $self->{data}[$pos] } ) );
             if ( $self->{rs}->count > 0 ) {
                 $r = $self->{rs}->find( @{ $self->{data}[$pos] } );
             } else {
@@ -206,10 +203,7 @@ sub get_field {
             $self->{log}->error( "No column named " . $id . " in row" );
         }
     }
-    $self->{log}->debug( "get_field "
-          . $id
-          . " value: "
-          . ( defined $value ? $value : "undef" ) );
+    # $self->{log}->debug( "get_field ". $id. " value: " . ( defined $value ? $value : "undef" ) );
     return $value;
 
 }
