@@ -225,8 +225,8 @@ sub query {
 
         my $local_sql;
         my @pks = $self->get_primarykeys();
-        $self->{log}->debug( "pks: " . join( ", ", @pks ) );
-        $self->{log}->debug( "select: " . $self->{sql}->{select} );
+	#$self->{log}->debug( "pks: " . join( ", ", @pks ) );
+	#$self->{log}->debug( "select: " . $self->{sql}->{select} );
 
         #if (  @{$self->{primary_keys}} = 0)
         $local_sql =
