@@ -108,22 +108,11 @@ sub set_field {
 
     #if ($key ~~ @{$self->{rocols}}){
     if ( grep( /^$key$/, @{ $self->{rocols} } ) ) {
-        $self->{log}->debug( "set_field: "
-              . $id
-              . " key: "
-              . $key
-              . " pos: "
-              . $pos
-              . " skipped since this is a readonly field." );
+        $self->{log}->debug( "set_field: " . $id . " key: " . $key . " pos: " . $pos . " skipped since this is a readonly field." );
+    } elsif (grep( /^$key$/, @{ $self->{ai_primary_keys} } )) {
+	$self->{log}->debug( "set_field: " . $id . " key: " . $key . " pos: " . $pos . " skipped since this is an ai primary key." );
     } else {
-        $self->{log}->debug( "set_field: "
-              . $id
-              . " key: "
-              . $key
-              . " pos: "
-              . $pos
-              . " value : "
-              . ( $value ? $value : "" ) );
+        $self->{log}->debug( "set_field: " . $id . " key: " . $key . " pos: ". $pos . " value : " . ( $value ? $value : "" ) );
         if ( $pos >= $self->row_count ) {
             $row = $self->{new_row};
         } else {
@@ -142,8 +131,9 @@ sub set_field {
 sub get_field {
     my ( $self, $id ) = @_;
     my $pos  = $self->{row}->{pos};
+    return unless defined $pos; #prevents cascade of errors when get_field is called on inexisting row
     my $last = $self->row_count;
-    $self->{log}->debug( "get_field: pos ", $pos, " last : ", $last );
+    #$self->{log}->debug( "get_field: pos ", $pos, " last : ", $last );
     my $row;
     if ( $pos < $last ) {
         $row = $self->{data}[$pos];
@@ -162,15 +152,11 @@ sub get_field {
 
     my $v;
     if ( length($rel) ) {
-        $self->{log}
-          ->debug( "get_field " . $id . " rel: " . $rel . " method: " . $m );
+	 # $self->{log}->debug( "get_field " . $id . " rel: " . $rel . " method: " . $m );
         $v = $row->{$rel}->$m()
           ; # or croak(__PACKAGE__ . "1 no method found to get value from the column " . $rel . " + " . $id);
     } else {
-        $self->{log}->debug( "get_field "
-              . $id
-              . " method: "
-              . ( defined $m ? $m : " undefined" ) );
+	#$self->{log}->debug( "get_field " . $id  . " method: " . ( defined $m ? $m : " undefined" ) );
         $v = $row->$m()
           ; # or croak(__PACKAGE__ . " no method found to get value from the column " . $id);
     }
@@ -182,7 +168,7 @@ sub save {
     my $self = shift;
     my $row;
     if ( $self->{new_row} ) {
-        $self->{log}->debug("Linker::RdbDataManager save new row ");
+        $self->{log}->debug(__PACKAGE__," save new row ");
         $row = $self->{new_row};
         push @{ $self->{data} }, $row;
         my $last = $self->row_count - 1;
@@ -190,11 +176,19 @@ sub save {
 
     } else {
         $self->{log}
-          ->debug( "Linker::RdbDataManager save at " . $self->{row}->{pos} );
+          ->debug( __PACKAGE__," save at " . $self->{row}->{pos} );
         my $pos = $self->{row}->{pos};
         $row = $self->{data}[$pos];
     }
     $self->{log}->debug("saving and unsetting new row");
+=for comment
+     my $m = $row->meta();
+     my @col = $m->columns;
+     $self->{log}->debug("acc ", join ( " " , $m->column_accessor_method_names));
+     for my $c (@col){
+ 	$self->{log}->debug("name: ", $c->name, " type ", $c->type);
+      }
+=cut
     my $done;
     $done = $row->save or carp("can't save ...\n");
     $self->{new_row} = undef;
@@ -259,10 +253,7 @@ sub row_count {
     my $self  = shift;
     my $hr    = $self->{row};
     my $count = scalar @{ $self->{data} };
-    $self->{log}->debug( "row_count last pos : "
-          . ( $hr->{last_row} ? $hr->{last_row} : -1 )
-          . " count: "
-          . $count );
+    # $self->{log}->debug( "row_count last pos : ". ( $hr->{last_row} ? $hr->{last_row} : -1 ). " count: ". $count );
     return $count;
 
 }
@@ -557,7 +548,7 @@ C<alias> is a hash ref of field (key) and array ref (alias list). For example if
 	    table   => 'speaks',
 
 	    columns => [
-        	speaksid  => { type => 'serial' },
+        	speaksid  => { type => 'serial'.not_null => 1 },
 	        countryid => { type => 'integer', not_null => 1 },
         	langid    => { type => 'integer', not_null => 1 },
     	],
