@@ -264,7 +264,7 @@ sub _get_rows_from_batch {
   # $local_sql .= " ( " . join( ",", $self->{keyset}[$counter] ) . " ),";
   #my @pk_vals = @{$all_pk_vals[$counter]};
   #my $value = $pk_val->[]
-  $self->{log}->debug("pk :", $pk, " value: ", $pk_val);
+  #$self->{log}->debug("pk :", $pk, " value: ", $pk_val);
  
    push @vals_for_pk, $pk_val unless ( $seen{$pk_val}++ );
 
@@ -494,7 +494,7 @@ sub delete {
 
 sub _execute {
     my ( $self, $sql, @bind ) = @_;
-    $self->{log}->debug( "_execute:", $sql );
+    #$self->{log}->debug( "_execute:", $sql );
     my $sth = $self->{dbh}->prepare($sql);
 
     #my $done=0;
